# Data Donation Module (ddm)

> **_NOTE:_**  This package is currently under active development.

**DDM** (Data Donation Module) is a Django application that helps researchers to
setup data donation projects and to collect data donations for academic research.

This is part of a larger initiative from the University of Zurich and the Digital
Society Initiative to strengthen the exchange about the topic of data donations and
promote this data collection approach. For more information, visit https://datadonation.uzh.ch.

Documentation: https://data-donation-module.readthedocs.io/en/latest/ \
PyPi: https://pypi.org/project/django-ddm/
